# stubs-py
![Continuous Integration](https://github.com/outcome-co/stubs-py/workflows/Continuous%20Integration/badge.svg) ![version-badge](https://img.shields.io/badge/version-0.5.3-brightgreen)

Stubs for various python packages.

They are often partial, sometimes incomplete.

## Usage

```sh
poetry add outcome-stubs
```

## Development

Remember to run `./bootstrap.sh` when you clone the repository.
